import React, { useMemo } from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import {
  Typography,
  List,
  ListItem,
  ListItemText,
  ListItemAvatar
} from "@material-ui/core";
import Avatar from "@material-ui/core/Avatar";
import WebAssetIcon from "@material-ui/icons/WebAsset";
import DnsRoundedIcon from "@material-ui/icons/DnsRounded";
import SettingsInputSvideoIcon from "@material-ui/icons/SettingsInputSvideo";
import { useTranslation } from "react-i18next";
import { useWindowSize } from "@flare/react-hooks";

const useStyles = makeStyles(theme => {
  return {
    horizontally: {
      display: "flex",
      flexDirection: "row",
      padding: 0
    },
    vertical: {
      width: "100%",
      maxWidth: 360
    },
    value: {
      fontSize: "0.9rem",
      fontWeight: theme.typography.fontWeightMedium
    }
  };
});

const SystemVersionComponent = ({ data }) => {
  const classes = useStyles();
  const { t } = useTranslation();
  const { isMobile } = useWindowSize();

  const listClassName = useMemo(
    () => (isMobile ? classes.vertical : classes.horizontally),
    [isMobile, classes.vertical, classes.horizontally]
  );

  const lastUpdateDate = useMemo(() => {
    const format = "DD-MM-YYYY HH:mm:ss";
    const server = t("DATE_FORMAT", {
      date: {
        value: data.server.lastUpdateDate,
        format
      }
    });

    const api = t("DATE_FORMAT", {
      date: {
        value: data.api.lastUpdateDate,
        format
      }
    });

    const frontend = t("DATE_FORMAT", {
      date: {
        value: process.env.APP_DATE,
        format
      }
    });

    return { server, api, frontend };
  }, [data, t]);

  return (
    <>
      <Typography variant="subtitle1" color="textSecondary">
        {t("System.Versions.Title")}
      </Typography>
      <List className={listClassName}>
        <ListItem>
          <ListItemAvatar>
            <Avatar>
              <DnsRoundedIcon />
            </Avatar>
          </ListItemAvatar>
          <ListItemText
            primary={
              <span className={classes.value}>
                {t("System.Versions.Server", {
                  version: data.server.version
                })}
              </span>
            }
            secondary={t("System.LastUpdateDate", {
              date: lastUpdateDate.server
            })}
          />
        </ListItem>
        <ListItem>
          <ListItemAvatar>
            <Avatar>
              <SettingsInputSvideoIcon />
            </Avatar>
          </ListItemAvatar>
          <ListItemText
            primary={
              <span className={classes.value}>
                {t("System.Versions.Api", {
                  version: data.api.version
                })}
              </span>
            }
            secondary={t("System.LastUpdateDate", {
              date: lastUpdateDate.api
            })}
          />
        </ListItem>
        <ListItem>
          <ListItemAvatar>
            <Avatar>
              <WebAssetIcon />
            </Avatar>
          </ListItemAvatar>
          <ListItemText
            primary={
              <span className={classes.value}>
                {t("System.Versions.Frontend", {
                  version: process.env.APP_VERSION
                })}
              </span>
            }
            secondary={t("System.LastUpdateDate", {
              date: lastUpdateDate.frontend
            })}
          />
        </ListItem>
      </List>
    </>
  );
};

SystemVersionComponent.propTypes = {
  data: PropTypes.object.isRequired
};

export default SystemVersionComponent;
